@@ -112,6 +112,16 @@ int event(int wait, int allow_dlgs)
 				return 1;
 			}
 			break;
+#if WITH_SDL2
+		 case SDL_WINDOWEVENT:
+			switch(ev.window.event) {
+			 case SDL_WINDOWEVENT_EXPOSED:
+			 case SDL_WINDOWEVENT_RESTORED:
+				scr_update(0, 0, 0, 0);
+				break;
+			}
+			break;
+#endif /* WITH_SDL2 */
 		}
 
 		ev_avail = SDL_PollEvent(&ev);
