@@ -27,7 +27,7 @@ const char SDLGui_fileid[] = "sdlgui.c : " __DATE__ " " __TIME__;
 
 #include "font8x16.h"
 
-#if WITH_SDL2
+#if WITH_SDL2 && !defined(SDL_SRCCOLORKEY)
 #define SDL_SRCCOLORKEY SDL_TRUE
 #endif
 
@@ -41,14 +41,16 @@ static SDL_Surface *pFontGfx = NULL;        /* The actual font graphics */
 static int current_object = 0;              /* Current selected object */
 static bool has_utf8;
 
-#if WITH_SDL2
-static inline int SDL_SetColors(SDL_Surface *surface, SDL_Color *colors,
+static inline int SDLGui_SetColors(SDL_Surface *surface, SDL_Color *colors,
                                 int firstcolor, int ncolors)
 {
+#if WITH_SDL2
 	return SDL_SetPaletteColors(surface->format->palette, colors,
 	                            firstcolor, ncolors);
-}
+#else
+	return SDL_SetColors(surface, colors, firstcolor, ncolors);
 #endif
+}
 
 /**
  * Load an 1 plane XBM into a 8 planes SDL_Surface.
@@ -110,7 +112,6 @@ int SDLGui_Init(void)
 	}
 
 	/* Initialize the font graphics: */
-//	pSmallFontGfx = SDLGui_LoadXBM(font5x8_width, font5x8_height, font5x8_bits);
 	pBigFontGfx = SDLGui_LoadXBM(font8x16_width, font8x16_height, font8x16_bits);
 	if (/*pSmallFontGfx == NULL ||*/ pBigFontGfx == NULL)
 	{
@@ -119,11 +120,9 @@ int SDLGui_Init(void)
 	}
 
 	/* Set color palette of the font graphics: */
-	//SDL_SetColors(pSmallFontGfx, blackWhiteColors, 0, 2);
-	SDL_SetColors(pBigFontGfx, blackWhiteColors, 0, 2);
+	SDLGui_SetColors(pBigFontGfx, blackWhiteColors, 0, 2);
 
 	/* Set font color 0 as transparent: */
-	//SDL_SetColorKey(pSmallFontGfx, SDL_SRCCOLORKEY, 0);
 	SDL_SetColorKey(pBigFontGfx, SDL_SRCCOLORKEY, 0);
 
 	/* Check for UTF-8 locale */
@@ -191,7 +190,7 @@ int SDLGui_SetScreen(SDL_Surface *pScrn)
 
 	if (pFontGfx == NULL)
 	{
-		fprintf(stderr, "Error: A problem with the font occured!\n");
+		fprintf(stderr, "Error: A problem with the font occurred!\n");
 		return -1;
 	}
 
@@ -240,7 +239,7 @@ static char SDLGui_Utf8ToLatin1(const char *txt, int *i)
 		return c;
 	}
 
-	/* Quick and dirty convertion for latin1 characters only... */
+	/* Quick and dirty conversion for latin1 characters only... */
 	if ((c & 0xc0) == 0xc0)
 	{
 		c = c << 6;
@@ -661,7 +660,7 @@ static void SDLGui_EditField(SGOBJ *dlg, int objnum)
 			SDL_FillRect(pSdlGuiScrn, &cursorrect, cursorCol);
 		}
 		SDLGui_Text(rect.x, rect.y, dlg[objnum].txt);  /* Draw text */
-		SDL_UpdateRects(pSdlGuiScrn, 1, &rect);
+		scr_update_rects(pSdlGuiScrn, 1, &rect);
 	}
 	while (!bStopEditing);
 
@@ -738,7 +737,7 @@ void SDLGui_DrawDialog(const SGOBJ *dlg)
 			break;
 		}
 	}
-	SDL_UpdateRect(pSdlGuiScrn, 0,0,0,0);
+	scr_update(0,0,0,0);
 }
 
 
@@ -805,8 +804,8 @@ static int SDLGui_SearchFlaggedButton(const SGOBJ *dlg, int flag)
 /*-----------------------------------------------------------------------*/
 /**
  * Show and process a dialog. Returns the button number that has been
- * pressed or SDLGUI_UNKNOWNEVENT if an unsupported event occured (will be
- * stored in parameter pEventOut).
+ * pressed or SDLGUI_UNKNOWNEVENT if an unsupported event occurred (will
+ * be stored in parameter pEventOut).
  */
 int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 {
@@ -842,7 +841,8 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 	                                  pSdlGuiScrn->format->Rmask, pSdlGuiScrn->format->Gmask, pSdlGuiScrn->format->Bmask, pSdlGuiScrn->format->Amask);
 	if (pSdlGuiScrn->format->palette != NULL)
 	{
-		SDL_SetColors(pBgSurface, pSdlGuiScrn->format->palette->colors, 0, pSdlGuiScrn->format->palette->ncolors-1);
+		SDLGui_SetColors(pBgSurface, pSdlGuiScrn->format->palette->colors, 0,
+		                 pSdlGuiScrn->format->palette->ncolors-1);
 	}
 
 	if (pBgSurface != NULL)
@@ -920,8 +920,11 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 					{
 						dlg[obj].state |= SG_SELECTED;
 						SDLGui_DrawButton(dlg, obj);
-						SDL_UpdateRect(pSdlGuiScrn, (dlg[0].x+dlg[obj].x)*sdlgui_fontwidth-2, (dlg[0].y+dlg[obj].y)*sdlgui_fontheight-2,
-						               dlg[obj].w*sdlgui_fontwidth+4, dlg[obj].h*sdlgui_fontheight+4);
+						rct.x = (dlg[0].x + dlg[obj].x) * sdlgui_fontwidth - 2;
+						rct.y = (dlg[0].y + dlg[obj].y) * sdlgui_fontheight - 2;
+						rct.w = dlg[obj].w * sdlgui_fontwidth + 4;
+						rct.h = dlg[obj].h * sdlgui_fontheight + 4;
+						scr_update_rects(pSdlGuiScrn, 1, &rct);
 						oldbutton=obj;
 					}
 					if (dlg[obj].type==SGSCROLLBAR)
@@ -974,7 +977,7 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 							rct.h = sdlgui_fontheight;
 							SDL_FillRect(pSdlGuiScrn, &rct, grey); /* Clear old */
 							SDLGui_DrawRadioButton(dlg, i);
-							SDL_UpdateRects(pSdlGuiScrn, 1, &rct);
+							scr_update_rects(pSdlGuiScrn, 1, &rct);
 						}
 						for (i = obj+1; dlg[i].type == SGRADIOBUT; i++)
 						{
@@ -985,7 +988,7 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 							rct.h = sdlgui_fontheight;
 							SDL_FillRect(pSdlGuiScrn, &rct, grey); /* Clear old */
 							SDLGui_DrawRadioButton(dlg, i);
-							SDL_UpdateRects(pSdlGuiScrn, 1, &rct);
+							scr_update_rects(pSdlGuiScrn, 1, &rct);
 						}
 						dlg[obj].state |= SG_SELECTED;  /* Select this radio button */
 						rct.x = (dlg[0].x+dlg[obj].x)*sdlgui_fontwidth;
@@ -994,7 +997,7 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 						rct.h = sdlgui_fontheight;
 						SDL_FillRect(pSdlGuiScrn, &rct, grey); /* Clear old */
 						SDLGui_DrawRadioButton(dlg, obj);
-						SDL_UpdateRects(pSdlGuiScrn, 1, &rct);
+						scr_update_rects(pSdlGuiScrn, 1, &rct);
 						break;
 					 case SGCHECKBOX:
 						dlg[obj].state ^= SG_SELECTED;
@@ -1004,13 +1007,16 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 						rct.h = sdlgui_fontheight;
 						SDL_FillRect(pSdlGuiScrn, &rct, grey); /* Clear old */
 						SDLGui_DrawCheckBox(dlg, obj);
-						SDL_UpdateRects(pSdlGuiScrn, 1, &rct);
+						scr_update_rects(pSdlGuiScrn, 1, &rct);
 						break;
 					 case SGPOPUP:
 						dlg[obj].state |= SG_SELECTED;
 						SDLGui_DrawPopupButton(dlg, obj);
-						SDL_UpdateRect(pSdlGuiScrn, (dlg[0].x+dlg[obj].x)*sdlgui_fontwidth-2, (dlg[0].y+dlg[obj].y)*sdlgui_fontheight-2,
-						               dlg[obj].w*sdlgui_fontwidth+4, dlg[obj].h*sdlgui_fontheight+4);
+						rct.x = (dlg[0].x + dlg[obj].x) * sdlgui_fontwidth - 2;
+						rct.y = (dlg[0].y + dlg[obj].y) * sdlgui_fontheight - 2;
+						rct.w = dlg[obj].w * sdlgui_fontwidth + 4;
+						rct.h = dlg[obj].h * sdlgui_fontheight + 4;
+						scr_update_rects(pSdlGuiScrn, 1, &rct);
 						retbutton=obj;
 						break;
 					}
@@ -1019,8 +1025,11 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 				{
 					dlg[oldbutton].state &= ~SG_SELECTED;
 					SDLGui_DrawButton(dlg, oldbutton);
-					SDL_UpdateRect(pSdlGuiScrn, (dlg[0].x+dlg[oldbutton].x)*sdlgui_fontwidth-2, (dlg[0].y+dlg[oldbutton].y)*sdlgui_fontheight-2,
-					               dlg[oldbutton].w*sdlgui_fontwidth+4, dlg[oldbutton].h*sdlgui_fontheight+4);
+					rct.x = (dlg[0].x + dlg[oldbutton].x) * sdlgui_fontwidth - 2;
+					rct.y = (dlg[0].y + dlg[oldbutton].y) * sdlgui_fontheight - 2;
+					rct.w = dlg[oldbutton].w * sdlgui_fontwidth + 4;
+					rct.h = dlg[oldbutton].h * sdlgui_fontheight + 4;
+					scr_update_rects(pSdlGuiScrn, 1, &rct);
 					oldbutton = 0;
 				}
 				if (obj >= 0 && (dlg[obj].flags&SG_EXIT))
@@ -1051,6 +1060,16 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 				}
 				break;
 
+#if WITH_SDL2
+			 case SDL_WINDOWEVENT:
+				if (sdlEvent.window.event == SDL_WINDOWEVENT_RESTORED
+				    || sdlEvent.window.event == SDL_WINDOWEVENT_EXPOSED)
+				{
+					scr_update(0, 0, 0, 0);
+				}
+				break;
+#endif /* WITH_SDL2 */
+
 			 default:
 				if (pEventOut)
 					retbutton = SDLGUI_UNKNOWNEVENT;
