@@ -170,7 +170,7 @@ int settings(void)
 		}
 	} while (!done);
 
-	SDL_UpdateRect(surf, 0,0, 0,0);
+	scr_update(0,0, 0,0);
 
 	if (settingsdlg[P1_HUMAN].state & SG_SELECTED)
 	{
@@ -370,5 +370,5 @@ void dlg_new_game(void)
 		bur[1]=ob1;
 	}
 
-	SDL_UpdateRect(surf, 0,0, 0,0);
+	scr_update(0,0, 0,0);
 }
